@@ -1046,7 +1046,6 @@ struct opendal_error *opendal_operator_delete(const struct opendal_operator *op,
  *
  * * If the `path` points to NULL, this function panics, i.e. exits with information
  */
-__attribute__((deprecated("Use opendal_operator_exists() instead.")))
 struct opendal_result_is_exist opendal_operator_is_exist(const struct opendal_operator *op,
                                                          const char *path);
 
@@ -1481,7 +1480,7 @@ struct opendal_error *opendal_writer_close(struct opendal_writer *ptr);
 void opendal_writer_free(struct opendal_writer *ptr);
 
 #ifdef __cplusplus
-} // extern "C"
-#endif // __cplusplus
+}  // extern "C"
+#endif  // __cplusplus
 
-#endif /* _OPENDAL_H */
+#endif  /* _OPENDAL_H */
